@@ -1,8 +1,10 @@
 from .sfw import *
 from .nsfw import *
+from .games import *
+from .data import *
 from .errors import *
 from .help import Help
 
 __title__ = "Estrapy-API"
-__version__ = "0.1.7"
+__version__ = "0.2.0"
 __author__ = "Stawa"
